==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/IstioIngressListenerFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface IstioIngressListenerFluent<A extends IstioIngressListenerFluent<A>> extends Fluent<A>{


    public String getBind();
    public A withBind(String bind);
    public Boolean hasBind();
    public A withNewBind(String arg1);
    public A withNewBind(StringBuilder arg1);
    public A withNewBind(StringBuffer arg1);
    public CaptureMode getCaptureMode();
    public A withCaptureMode(CaptureMode captureMode);
    public Boolean hasCaptureMode();
    public String getDefaultEndpoint();
    public A withDefaultEndpoint(String defaultEndpoint);
    public Boolean hasDefaultEndpoint();
    public A withNewDefaultEndpoint(String arg1);
    public A withNewDefaultEndpoint(StringBuilder arg1);
    public A withNewDefaultEndpoint(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Port getPort();
    public me.snowdrop.istio.api.networking.v1alpha3.Port buildPort();
    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.Port port);
    public Boolean hasPort();
    public A withNewPort(String name,Integer number,String protocol);
    public IstioIngressListenerFluent.PortNested<A> withNewPort();
    public IstioIngressListenerFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);
    public IstioIngressListenerFluent.PortNested<A> editPort();
    public IstioIngressListenerFluent.PortNested<A> editOrNewPort();
    public IstioIngressListenerFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortFluent<IstioIngressListenerFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/IstioIngressListenerFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface IstioIngressListenerFluent<A extends IstioIngressListenerFluent<A>> extends Fluent<A>{


    public String getBind();
    public A withBind(String bind);
    public Boolean hasBind();
    public A withNewBind(String arg1);
    public A withNewBind(StringBuilder arg1);
    public A withNewBind(StringBuffer arg1);
    public CaptureMode getCaptureMode();
    public A withCaptureMode(CaptureMode captureMode);
    public Boolean hasCaptureMode();
    public String getDefaultEndpoint();
    public A withDefaultEndpoint(String defaultEndpoint);
    public Boolean hasDefaultEndpoint();
    public A withNewDefaultEndpoint(String arg1);
    public A withNewDefaultEndpoint(StringBuilder arg1);
    public A withNewDefaultEndpoint(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public Port getPort();
    public Port buildPort();
    public A withPort(Port port);
    public Boolean hasPort();
    public A withNewPort(String name,Integer number,String protocol,Integer targetPort);
    public IstioIngressListenerFluent.PortNested<A> withNewPort();
    public IstioIngressListenerFluent.PortNested<A> withNewPortLike(Port item);
    public IstioIngressListenerFluent.PortNested<A> editPort();
    public IstioIngressListenerFluent.PortNested<A> editOrNewPort();
    public IstioIngressListenerFluent.PortNested<A> editOrNewPortLike(Port item);

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortFluent<IstioIngressListenerFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}


}
